View source: R/combine_classifications.R
| combine_classifications | R Documentation |
Combine hierarchical classifications by stacking one classification after another.
combine_classifications(..., sep = ".")
... |
A collection of lists, one for each classification, each giving
the "digits" that represent each level in the hierarchy, as made
by |
sep |
A character used to separate the classifications in |
A list with a entry for each level in the combined classification.
# Combine an unbalanced industry classification with a balanced
# geographic classification
industry <- c("111", "112", "12")
region <- c("11", "21", "22")
combine_classifications(
expand_classification(industry, pad = "0"),
expand_classification(region)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.