Methods to get and set the levels for a price index.
Arguments
- x
[piar_index]A price index, as made by, e.g.,elementary_index().- value
[character]A character vector, or something that can be coerced into one, giving the replacement levels forx.
Value
levels() returns a character vector with the levels for a price index.
The replacement method returns a copy of x with the levels in value.
(set_levels() is an alias that's easier to use with pipes.)