View source: R/levels.piar_index.R
| levels.piar_index | R Documentation |
Methods to get and set the levels for a price index.
## S3 method for class 'piar_index'
levels(x)
## S3 replacement method for class 'piar_index'
levels(x) <- value
set_levels(x, value)
x |
A price index, as made by, e.g., |
value |
A character vector, or something that can be coerced into one,
giving the replacement levels for |
levels() returns a character vector with the levels for a price index.
The replacement method returns a copy of x with the levels in value.
(set_levels() is an alias that's easier to use with pipes.)
Other index methods:
[.piar_index(),
aggregate.piar_index,
as.data.frame.piar_index(),
as.ts.piar_index(),
chain(),
contrib(),
head.piar_index(),
is.na.piar_index(),
mean.piar_index,
merge.piar_index(),
split.piar_index(),
stack.piar_index(),
time.piar_index(),
window.piar_index()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.