Calculate a weighted (outer) generalized mean of two (inner) generalized means (i.e., crossing means).
Arguments
- x
[numeric > 0]A strictly positive numeric vector.- weights
[list]A list of positive numeric vector of weights, each the same length asx, for both of the inner generalized means.NULLelements ofweightsequally weight each element ofx. The default uses equal weights for both inner generalized mean.- order
[numeric(2)]A finite numeric vector giving the order of each of the inner generalized means. The default computes an arithmetic mean and a harmonic mean.- outer_weights
[numeric(2)]A strictly positive numeric vector weights for each of the inner generalized means as used in the outer generalized mean. The default weights each inner generalized mean equally.- outer_order
[numeric(1)]A finite number giving the order of the outer generalized mean. The default uses a geometric mean.- na.rm
[logical(1)]Should missing values inxandweightsbe removed? By default missing values are not removed. Note that removal of missing values is balanced acrossxand both elements ofweights.
See also
Other math functions:
emean(),
gmean(),
scale_weights(),
transmute_weights(),
transmute_weights2(),
update_weights()