Learn R Programming

piar (version 0.10.1)

scale_weights: Scale weights

Description

Scale a vector of weights so that they sum to 1.

Usage

scale_weights(x)

Value

A numeric vector that sums to 1. If there are NAs in x then the result sums 1 to if these values are removed.

Arguments

x

[numeric >= 0] A positive numeric vector with at least one non-zero element.

See Also

Other math functions: emean(), gmean(), nested_gmean(), transmute_weights(), transmute_weights2(), update_weights()

Examples

Run this code
scale_weights(1:5)

scale_weights(c(1:5, NA))

Run the code above in your browser using DataLab